About
=====

The `Diofant`_ project is a fork of the `SymPy`_, started by Sergey B
Kirpichev, last reqular SymPy's commit is cbdd072 (22 Feb 2015).  The
git history goes back to 2007, when development was in svn.

The project was named after the Diophantus of Alexandria.  His "Arithmetica" is
one of the earliest known text that use symbols in equations.  "Diofant" is a
transliteration of Диофант, from Russian.

License
-------

Unless stated otherwise, all files in the Diofant project are licensed
using the new BSD license:

.. literalinclude:: ../LICENSE
    :language: none

SymPy Development Team
----------------------

SymPy is a team project and it was developed by a lot of people.

All people who contributed in the Diofant project via SymPy by sending
at least a patch or more (in the order of the date of their first
contribution) are listed here.  This list was generated automatically
from the git history by SymPy tools (people with a \* next
to their names are not found in the metadata of the git history).

Please note that this list is incomplete intentionally, because
some former SymPy developers don't want to be mentioned in the
context of the SymPy or derived projects.

* Ondřej Čertík
* Fabian Pedregosa
* Mateusz Paprocki
* Jason Gedge
* Marc-Etienne M.Leveille\*
* Brian Jorgensen
* Robert Schwarz
* Fredrik Johansson
* Chris Wu
* Pearu Peterson
* Ulrich Hecht\*
* Sebastian Krämer
* Goutham Lakshminarayan
* David Lawrence
* Jaroslaw Tworek
* David Marek
* Bernhard R. Link
* Andrej Tokarčík
* Or Dvory
* Saroj Adhikari
* Pauli Virtanen
* Robert Kern
* James Aspnes
* Jurjen N.E. Bos
* Nimish Telang
* Abderrahim Kitouni
* Pan Peng
* Friedrich Hagedorn
* Elrond der Elbenfuerst
* Rizgar Mella
* Felix Kaiser
* Roberto Nobrega
* David Roberts
* Vinzent Steinberg
* Case Van Horsen\*
* Riccardo Gori
* Štěpán Roučka
* Ali Raza Syed
* Stefano Maggiolo
* Robert Cimrman
* Bastian Weber
* Sebastian Krause
* Dan\*
* Sebastian Kreft
* Alan Bromborsky
* Boris Timokhin
* Robert (average.programmer)
* Andy R. Terrel
* Hubert Tsang
* Konrad Meyer
* Henrik Johansson
* Priit Laes
* Freddie Witherden
* Brian E. Granger
* Andrew Straw
* Kaifeng Zhu
* Ted Horst
* Aaron Meurer
* Akshay Srinivasan
* Andrew Docherty
* Barry Wardell
* Tomasz Buchert
* Vinay Kumar
* Johann Cohen-Tanugi
* Jochen Voss
* Luke Peterson
* Thomas Sidoti
* Chris Smith
* Florian Mickler
* Nicolas Pourcelot
* Ben Goodrich
* Toon Verstraelen
* Ronan Lamy
* James Abbatiello
* Ryan Krauss
* Bill Flynn
* Jorn Baayen
* Eh Tan
* Renato Coutinho
* Kevin Goodsell
* Oscar Benjamin
* Øyvind Jensen
* Julio Idichekop Filho
* Chu-Ching Huang\*
* Łukasz Pankowski
* Fernando Perez
* Raffaele De Feo
* Christian Muise
* Matt Curry
* Kazuo Thow
* Christian Schubert
* Jezreel Ng
* Matthew Brett
* James Pearson
* Addison Cugini
* Nicholas J.S. Kinar
* Harold Erbin
* Thomas Dixon
* Cristóvão Sousa
* Andre de Fortier Smit
* Mark Dewing
* Alexey U. Gudchenko
* Gary Kerr
* Sherjil Ozair
* Oleksandr Gituliar
* Sean Vig
* Prafullkumar P. Tale
* Vladimir Perić
* Tom Bachmann
* Yuri Karadzhov
* Vladimir Lagunov
* Matthew Rocklin
* Saptarshi Mandal
* Gilbert Gede
* Anatolii Koval
* Tomo Lazovich
* Pavel Fedotov
* Jack McCaffery
* Jeremias Yehdegho
* Kibeom Kim
* Gregory Ksionda
* Tomáš Bambas
* Raymond Wong
* Luca Weihs
* Shai 'Deshe' Wyborski
* Thomas Wiecki
* Óscar Nájera
* Mario Pernici
* Benjamin McDonald
* Sam Magura
* Stefan Krastanov
* Bradley Froehle
* Min Ragan-Kelley
* Emma Hogan
* Nikhil Sarda
* Julien Rioux
* Roberto Colistete, Jr.
* Raoul Bourquin
* Gert-Ludwig Ingold
* Srinivas Vasudevan
* Jason Moore
* Miha Marolt
* Tim Lahey
* Luis Garcia
* Matt Rajca
* David Li
* Alexandr Gudulin
* Bilal Akhtar
* Grzegorz Świrski
* Matt Habel
* David Ju
* Nichita Utiu
* Nikolay Lazarov
* Steve Anton
* Imran Ahmed Manzoor
* Ljubiša Moćić
* Piotr Korgul
* Jim Zhang
* Sam Sleight
* tsmars15
* Chancellor Arkantos
* Stepan Simsa
* Tobias Lenz
* Siddhanathan Shanmugam
* Tiffany Zhu
* Tristan Hume
* Alexey Subach
* Joan Creus
* Geoffry Song
* Puneeth Chaganti
* Marcin Kostrzewa
* Natalia Nawara
* vishal
* Shruti Mangipudi
* Davy Mao
* Swapnil Agarwal
* Kendhia
* jerryma1121
* Joachim Durchholz
* Martin Povišer
* Siddhant Jain
* Kevin Hunter
* Michael Mayorov
* Nathan Alison
* Christian Bühler
* Carsten Knoll
* M R Bharath
* Matthias Toews
* Sergiu Ivanov
* Jorge E. Cardona
* Sanket Agarwal
* Manoj Babu K.
* Sai Nikhil
* Aleksandar Makelov
* Sachin Irukula
* Raphael Michel
* Ashwini Oruganti
* Andreas Kloeckner
* Prateek Papriwal
* Arpit Goyal
* Angadh Nanjangud
* Comer Duncan
* Jens H. Nielsen
* Joseph Dougherty
* marshall2389
* Guru Devanla
* George Waksman
* Alexandr Popov
* Tarun Gaba
* Takafumi Arakaki
* Saurabh Jha
* Rom le Clair
* Angus Griffith
* Timothy Reluga
* Brian Stephanik
* Alexander Eberspächer
* Sachin Joglekar
* Tyler Pirtle
* Vasily Povalyaev
* Colleen Lee
* Matthew Hoff
* Niklas Thörne
* Huijun Mai
* Marek Šuppa
* Ramana Venkata
* Prasoon Shukla
* Stefen Yin
* Thomas Hisch
* Madeleine Ball
* Case Van Horsen
* Mary Clark
* Rishabh Dixit
* Manoj Kumar
* Akshit Agarwal
* CJ Carey
* Patrick Lacasse
* Ananya H
* Tarang Patel
* Christopher Dembia
* Benjamin Fishbein
* Sean Ge
* Amit Jamadagni
* Ankit Agrawal
* Björn Dahlgren
* Christophe Saint-Jean
* Demian Wassermann
* Khagesh Patel
* Stephen Loo
* hm
* Patrick Poitras
* Katja Sophie Hotz
* Varun Joshi
* Chetna Gupta
* Thilina Rathnayake
* Max Hutchinson
* Shravas K Rao
* Matthew Tadd
* Alexander Hirzel
* Randy Heydon
* Oliver Lee
* Seshagiri Prabhu
* Pradyumna
* Erik Welch
* Eric Nelson
* Roland Puntaier
* Chris Conley
* Tim Swast
* Dmitry Batkovich
* Francesco Bonazzi
* Yuriy Demidov
* Rick Muller
* Manish Gill
* Markus Müller
* Amit Saha
* Jeremy
* QuaBoo
* Stefan van der Walt
* David Joyner
* Lars Buitinck
* Alkiviadis G. Akritas
* Vinit Ravishankar
* Mike Boyle
* Heiner Kirchhoffer
* Pablo Puente
* James Fiedler
* Harsh Gupta
* Tuomas Airaksinen
* Paul Strickland
* James Goppert
* rathmann
* Avichal Dayal
* Paul Scott
* Shipra Banga
* Pramod Ch
* Akshay
* Buck Shlegeris
* Jonathan Miller
* Edward
* Rajath S
* Zamrath Nizam
* Aditya Shah
* Rajat Aggarwal
* Sambuddha Basu
* Zeel Shah
* Abhinav Chanda
* Jim Crist
* Sudhanshu Mishra
* Anurag Sharma
* Soumya Dipta Biswas
* Sushant Hiray
* Ben Lucato
* Kunal Arora
* Henry Gebhardt
* Dammina Sahabandu
* Shukla
* Ralph Bean
* richierichrawr
* John Connor
* Juan Luis Cano Rodríguez
* Sahil Shekhawat
* Kundan Kumar
* Stas Kelvich
* sevaader
* Dhruvesh Vijay Parikh
* Venkatesh Halli
* Lennart Fricke
* Vlad Seghete
* shashank-agg
* carstimon
* Pierre Haessig
* Maciej Baranski
* Benjamin Gudehus
* Faisal Anees
* Mark Shoulson
* Robert Johansson
* Kalevi Suominen
* Kaushik Varanasi
* Fawaz Alazemi
* Ambar Mehrotra
* David P. Sanders
* Peter Brady
* John V. Siratt
* Sarwar Chahal
* Nathan Woods
* Colin B. Macdonald
* Marcus Näslund
* Clemens Novak
* Mridul Seth
* Craig A. Stoudt
* Raj
* Mihai A. Ionescu
* immerrr
* Chai Wah Wu
* Leonid Blouvshtein
* Peleg Michaeli
* ck Lux
* zsc347
* Hamish Dickson
* Michael Gallaspy
* Roman Inflianskas
* Duane Nykamp
* Ted Dokos
* Sunny Aggarwal
* Victor Brebenar
* Akshat Jain
* Shivam Vats
* WANG Longqi
* Juan Felipe Osorio
* GitRay
* Lukas Zorich
* Eric Miller
* Cody Herbst
* Nishith Shah
* AMiT Kumar
* Yury G. Kudryashov
* Guillaume Gay
* Ray Cathcart
* Mihir Wadwekar
* Tuan Manh Lai
* Asish Panda
* Darshan Chaudhary
* Alec Kalinin
* Ralf Stephan
* Aaditya Nair
* Jayesh Lahori
* harshil goel
* Luv Agarwal
* Jason Ly
* Lokesh Sharma
* Sartaj Singh
* Chris Swierczewski
* vizietto
* Juha Remes
* Peter Schmidt
* Jiaxing Liang
* Lucas Jones
* Greg Ashton - LianLi
* jennifercw
* Michael Boyle
* Mathew Chong
* Govind Sahai
* Adam Bloomston
* Kyle McDaniel
* Nguyen Truong Duy
* Gaurav Dhingra
* Kevin Ventullo
* mao8
* Richard Otis
* Rich LaSota
* Anton Akhmerov
* David T
* Jason Siefken
* Matthew Thomas
* Sumith1896
* Akshay Nagar
* Yu Kobayashi
* Shashank Kumar
* Tschijnmo TSCHAU
* Jens Jørgen Mortensen
* Dzhelil Rufat
* Prashant Tyagi
* Matthew Davis
* Jacob Garber
* Justin Blythe
* Moo VI
* Keval Shah
* Kshitij Saraogi
* Isuru Fernando
* Meghana Madhyastha
* Tanu Hari Dixit
* Dustin Gadal

Brief History
-------------

`SymPy`_ was started by Ondřej Čertík in 2005, he wrote some code during the
summer, then he wrote some more code during the summer 2006. In February 2007,
Fabian Pedregosa joined the project and helped fixed many things, contributed
documentation and made it alive again. 5 students (Mateusz Paprocki, Brian
Jorgensen, Jason Gedge, Robert Schwarz and Chris Wu) improved SymPy incredibly
during the summer 2007 as part of the Google Summer of Code (GSoC). Pearu Peterson
joined the development during the summer 2007 and he has made SymPy much more
competitive and fast (from 10x to 100x) by rewriting the core from scratch.
Jurjen N.E. Bos has contributed pretty printing and other patches.
Fredrik Johansson has wrote mpmath and contributed a lot of patches.

SymPy has participated in every GSoC since 2007.  Moderate amount
of SymPy's development has come from GSoC students.

In 2011, Ondřej Čertík stepped down as lead developer, with Aaron Meurer, who
also started as a GSoC student, taking his place.

Ondřej Čertík is still active in the community, but is too busy with work
and family to play a lead development role.  Unfortunately, his remaining
activity neither constructive nor productive anymore and SymPy just
slowly dying now: most former contributors are inactive now or
explicitely leave this "friendly and welcoming" project.

This unfortunate situation was major reason to fork the
SymPy as the `Diofant`_ project.  Development in the new project will
be open and public, without hidden double standards, centered about
good, proved code and not project popularity counters.  Here we believe
that mathematical correctness is more important than political one.

.. _SymPy : http://www.sympy.org/
.. _Diofant : http://diofant.rtfd.io/
